==> hal-meta-0.7.1.jar: org/jboss/hal/meta/description/ResourceDescriptionStatementContext.java <==
/*
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.hal.meta.description;

import org.jboss.hal.config.Environment;
import org.jboss.hal.meta.FilteringStatementContext;
import org.jboss.hal.meta.StatementContext;

import static org.jboss.hal.meta.SelectionAwareStatementContext.SELECTION_KEY;

/**
 * @author Harald Pehl
 */
public class ResourceDescriptionStatementContext extends FilteringStatementContext {

    public ResourceDescriptionStatementContext(final StatementContext delegate, final Environment environment) {
        super(delegate, new Filter() {
            @Override
            public String filter(final String placeholder) {
                if (SELECTION_KEY.equals(placeholder)) {
                    return "*";
                }
                return delegate.resolve(placeholder);
            }

            @Override
            public String[] filterTuple(final String placeholder) {
                if (!environment.isStandalone()) {
                    Tuple t = Tuple.from(placeholder);
                    if (t != null) {
                        return new String[]{t.resource(), "*"};
                    }
                }
                return delegate.resolveTuple(placeholder);
            }
        });
    }
}

==> hal-meta-0.9.4-20171212.073042-27.jar: org/jboss/hal/meta/description/ResourceDescriptionStatementContext.java <==
/*
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.hal.meta.description;

import org.jboss.hal.config.Environment;
import org.jboss.hal.meta.FilteringStatementContext;
import org.jboss.hal.meta.StatementContext;

import static org.jboss.hal.meta.SelectionAwareStatementContext.SELECTION_KEY;

public class ResourceDescriptionStatementContext extends FilteringStatementContext {

    public ResourceDescriptionStatementContext(StatementContext delegate, Environment environment) {
        super(delegate, new Filter() {
            @Override
            public String filter(String placeholder) {
                if (SELECTION_KEY.equals(placeholder)) {
                    return "*";
                }
                return delegate.resolve(placeholder);
            }

            @Override
            public String[] filterTuple(String placeholder) {
                if (!environment.isStandalone()) {
                    Tuple t = Tuple.from(placeholder);
                    if (t != null) {
                        return new String[]{t.resource(), "*"};
                    }
                }
                return delegate.resolveTuple(placeholder);
            }
        });
    }
}
